diff --git a/docs/proto/proto-docs.md b/docs/proto/proto-docs.md
index 995650af18..f6c0182b6d 100644
--- a/docs/proto/proto-docs.md
+++ b/docs/proto/proto-docs.md
@@ -45,8 +45,8 @@
- [MsgIBCSend](#cosmwasm.wasm.v1.MsgIBCSend)
- [cosmwasm/wasm/v1/proposal.proto](#cosmwasm/wasm/v1/proposal.proto)
+ - [AccessConfigUpdate](#cosmwasm.wasm.v1.AccessConfigUpdate)
- [ClearAdminProposal](#cosmwasm.wasm.v1.ClearAdminProposal)
- - [CodeAccessConfigUpdate](#cosmwasm.wasm.v1.CodeAccessConfigUpdate)
- [ExecuteContractProposal](#cosmwasm.wasm.v1.ExecuteContractProposal)
- [InstantiateContractProposal](#cosmwasm.wasm.v1.InstantiateContractProposal)
- [MigrateContractProposal](#cosmwasm.wasm.v1.MigrateContractProposal)
@@ -643,35 +643,35 @@ MsgIBCSend
-
+
-### ClearAdminProposal
-ClearAdminProposal gov proposal content type to clear the admin of a
-contract.
+### AccessConfigUpdate
+AccessConfigUpdate contains the code id and the access config to be
+applied.
| Field | Type | Label | Description |
| ----- | ---- | ----- | ----------- |
-| `title` | [string](#string) | | Title is a short summary |
-| `description` | [string](#string) | | Description is a human readable text |
-| `contract` | [string](#string) | | Contract is the address of the smart contract |
+| `code_id` | [uint64](#uint64) | | CodeID is the reference to the stored WASM code to be updated |
+| `instantiate_permission` | [AccessConfig](#cosmwasm.wasm.v1.AccessConfig) | | InstantiatePermission to apply to the set of code ids |
-
+
-### CodeAccessConfigUpdate
-CodeAccessConfigUpdate contains the code id and the access config to be
-applied.
+### ClearAdminProposal
+ClearAdminProposal gov proposal content type to clear the admin of a
+contract.
| Field | Type | Label | Description |
| ----- | ---- | ----- | ----------- |
-| `code_id` | [uint64](#uint64) | | CodeID is the reference to the stored WASM code to be updated |
-| `instantiate_permission` | [AccessConfig](#cosmwasm.wasm.v1.AccessConfig) | | InstantiatePermission to apply to the set of code ids |
+| `title` | [string](#string) | | Title is a short summary |
+| `description` | [string](#string) | | Description is a human readable text |
+| `contract` | [string](#string) | | Contract is the address of the smart contract |
@@ -845,7 +845,7 @@ instantiate config to a set of code ids.
| ----- | ---- | ----- | ----------- |
| `title` | [string](#string) | | Title is a short summary |
| `description` | [string](#string) | | Description is a human readable text |
-| `code_updates` | [CodeAccessConfigUpdate](#cosmwasm.wasm.v1.CodeAccessConfigUpdate) | repeated | CodeAccessConfigUpdate contains the list of code ids and the access config to be applied. |
+| `access_config_updates` | [AccessConfigUpdate](#cosmwasm.wasm.v1.AccessConfigUpdate) | repeated | AccessConfigUpdate contains the list of code ids and the access config to be applied. |
diff --git a/x/wasm/client/cli/gov_tx.go b/x/wasm/client/cli/gov_tx.go
index aede9bc81c..2a044c2d42 100644
--- a/x/wasm/client/cli/gov_tx.go
+++ b/x/wasm/client/cli/gov_tx.go
@@ -632,8 +632,8 @@ func parseAccessConfig(config string) (types.AccessConfig, error) {
}
}
-func parseCodeUpdateArgs(args []string) ([]types.CodeAccessConfigUpdate, error) {
- updates := make([]types.CodeAccessConfigUpdate, len(args))
+func parseAccessConfigUpdates(args []string) ([]types.AccessConfigUpdate, error) {
+ updates := make([]types.AccessConfigUpdate, len(args))
for i, c := range args {
// format: code_id,access_config
// access_config: nobody|everybody|address
@@ -651,7 +651,7 @@ func parseCodeUpdateArgs(args []string) ([]types.CodeAccessConfigUpdate, error)
if err != nil {
return nil, err
}
- updates[i] = types.CodeAccessConfigUpdate{
+ updates[i] = types.AccessConfigUpdate{
CodeID: codeID,
InstantiatePermission: accessConfig,
}
@@ -692,15 +692,15 @@ $ %s tx gov submit-proposal update-instantiate-config 1,nobody 2,everybody 3,%s1
if err != nil {
return err
}
- updates, err := parseCodeUpdateArgs(args)
+ updates, err := parseAccessConfigUpdates(args)
if err != nil {
return err
}
content := types.UpdateInstantiateConfigProposal{
- Title: proposalTitle,
- Description: proposalDescr,
- CodeUpdates: updates,
+ Title: proposalTitle,
+ Description: proposalDescr,
+ AccessConfigUpdates: updates,
}
msg, err := govtypes.NewMsgSubmitProposal(&content, deposit, clientCtx.GetFromAddress())
if err != nil {
diff --git a/x/wasm/client/rest/gov.go b/x/wasm/client/rest/gov.go
index 70685a7646..d62381039f 100644
--- a/x/wasm/client/rest/gov.go
+++ b/x/wasm/client/rest/gov.go
@@ -421,19 +421,18 @@ func UnpinCodeProposalHandler(cliCtx client.Context) govrest.ProposalRESTHandler
type UpdateInstantiateConfigProposalJSONReq struct {
BaseReq rest.BaseReq `json:"base_req" yaml:"base_req"`
- Title string `json:"title" yaml:"title"`
- Description string `json:"description" yaml:"description"`
- Proposer string `json:"proposer" yaml:"proposer"`
- Deposit sdk.Coins `json:"deposit" yaml:"deposit"`
-
- CodeUpdates []types.CodeAccessConfigUpdate `json:"code_updates" yaml:"code_updates"`
+ Title string `json:"title" yaml:"title"`
+ Description string `json:"description" yaml:"description"`
+ Proposer string `json:"proposer" yaml:"proposer"`
+ Deposit sdk.Coins `json:"deposit" yaml:"deposit"`
+ AccessConfigUpdates []types.AccessConfigUpdate `json:"access_config_updates" yaml:"access_config_updates"`
}
func (s UpdateInstantiateConfigProposalJSONReq) Content() govtypes.Content {
return &types.UpdateInstantiateConfigProposal{
- Title: s.Title,
- Description: s.Description,
- CodeUpdates: s.CodeUpdates,
+ Title: s.Title,
+ Description: s.Description,
+ AccessConfigUpdates: s.AccessConfigUpdates,
}
}
func (s UpdateInstantiateConfigProposalJSONReq) GetProposer() string {
diff --git a/x/wasm/keeper/proposal_handler.go b/x/wasm/keeper/proposal_handler.go
index c0fef8c847..9da330ce0f 100644
--- a/x/wasm/keeper/proposal_handler.go
+++ b/x/wasm/keeper/proposal_handler.go
@@ -229,9 +229,9 @@ func handleUpdateInstantiateConfigProposal(ctx sdk.Context, k types.ContractOpsK
return err
}
- for _, codeUpdate := range p.CodeUpdates {
- if err := k.SetAccessConfig(ctx, codeUpdate.CodeID, codeUpdate.InstantiatePermission); err != nil {
- return sdkerrors.Wrapf(err, "code id: %d", codeUpdate.CodeID)
+ for _, accessConfigUpdate := range p.AccessConfigUpdates {
+ if err := k.SetAccessConfig(ctx, accessConfigUpdate.CodeID, accessConfigUpdate.InstantiatePermission); err != nil {
+ return sdkerrors.Wrapf(err, "code id: %d", accessConfigUpdate.CodeID)
}
}
return nil
diff --git a/x/wasm/keeper/proposal_integration_test.go b/x/wasm/keeper/proposal_integration_test.go
index 523c5bed9c..441e75fd75 100644
--- a/x/wasm/keeper/proposal_integration_test.go
+++ b/x/wasm/keeper/proposal_integration_test.go
@@ -769,38 +769,38 @@ func TestUpdateInstantiateConfigProposal(t *testing.T) {
)
specs := map[string]struct {
- codeUpdates []types.CodeAccessConfigUpdate
- expErr bool
+ accessConfigUpdates []types.AccessConfigUpdate
+ expErr bool
}{
"update one": {
- codeUpdates: []types.CodeAccessConfigUpdate{
+ accessConfigUpdates: []types.AccessConfigUpdate{
{CodeID: nobody.CodeID, InstantiatePermission: types.AllowEverybody},
},
},
"update multiple": {
- codeUpdates: []types.CodeAccessConfigUpdate{
+ accessConfigUpdates: []types.AccessConfigUpdate{
{CodeID: everybody.CodeID, InstantiatePermission: types.AllowNobody},
{CodeID: nobody.CodeID, InstantiatePermission: withAddressAccessConfig},
{CodeID: withAddress.CodeID, InstantiatePermission: types.AllowEverybody},
},
},
"update same code id": {
- codeUpdates: []types.CodeAccessConfigUpdate{
+ accessConfigUpdates: []types.AccessConfigUpdate{
{CodeID: everybody.CodeID, InstantiatePermission: types.AllowNobody},
{CodeID: everybody.CodeID, InstantiatePermission: types.AllowEverybody},
},
expErr: true,
},
"update non existing code id": {
- codeUpdates: []types.CodeAccessConfigUpdate{
+ accessConfigUpdates: []types.AccessConfigUpdate{
{CodeID: 100, InstantiatePermission: types.AllowNobody},
{CodeID: everybody.CodeID, InstantiatePermission: types.AllowEverybody},
},
expErr: true,
},
"update empty list": {
- codeUpdates: make([]types.CodeAccessConfigUpdate, 0),
- expErr: true,
+ accessConfigUpdates: make([]types.AccessConfigUpdate, 0),
+ expErr: true,
},
}
parentCtx := ctx
@@ -809,18 +809,18 @@ func TestUpdateInstantiateConfigProposal(t *testing.T) {
ctx, _ := parentCtx.CacheContext()
- updates := make([]types.CodeAccessConfigUpdate, 0)
- for _, cu := range spec.codeUpdates {
- updates = append(updates, types.CodeAccessConfigUpdate{
+ updates := make([]types.AccessConfigUpdate, 0)
+ for _, cu := range spec.accessConfigUpdates {
+ updates = append(updates, types.AccessConfigUpdate{
CodeID: cu.CodeID,
InstantiatePermission: cu.InstantiatePermission,
})
}
proposal := types.UpdateInstantiateConfigProposal{
- Title: "Foo",
- Description: "Bar",
- CodeUpdates: updates,
+ Title: "Foo",
+ Description: "Bar",
+ AccessConfigUpdates: updates,
}
// when stored
@@ -837,9 +837,9 @@ func TestUpdateInstantiateConfigProposal(t *testing.T) {
require.NoError(t, gotErr)
// then
- for i := range spec.codeUpdates {
- c := wasmKeeper.GetCodeInfo(ctx, spec.codeUpdates[i].CodeID)
- require.Equal(t, spec.codeUpdates[i].InstantiatePermission, c.InstantiateConfig)
+ for i := range spec.accessConfigUpdates {
+ c := wasmKeeper.GetCodeInfo(ctx, spec.accessConfigUpdates[i].CodeID)
+ require.Equal(t, spec.accessConfigUpdates[i].InstantiatePermission, c.InstantiateConfig)
}
})
}
diff --git a/x/wasm/types/proposal.go b/x/wasm/types/proposal.go
index a4cefc0010..748a03895b 100644
--- a/x/wasm/types/proposal.go
+++ b/x/wasm/types/proposal.go
@@ -570,11 +570,11 @@ func (p UpdateInstantiateConfigProposal) ValidateBasic() error {
if err := validateProposalCommons(p.Title, p.Description); err != nil {
return err
}
- if len(p.CodeUpdates) == 0 {
+ if len(p.AccessConfigUpdates) == 0 {
return sdkerrors.Wrap(ErrEmpty, "code updates")
}
dedup := make(map[uint64]bool)
- for _, codeUpdate := range p.CodeUpdates {
+ for _, codeUpdate := range p.AccessConfigUpdates {
_, found := dedup[codeUpdate.CodeID]
if found {
return sdkerrors.Wrapf(ErrDuplicate, "duplicate code: %d", codeUpdate.CodeID)
@@ -592,13 +592,13 @@ func (p UpdateInstantiateConfigProposal) String() string {
return fmt.Sprintf(`Update Instantiate Config Proposal:
Title: %s
Description: %s
- CodeUpdates: %v
-`, p.Title, p.Description, p.CodeUpdates)
+ AccessConfigUpdates: %v
+`, p.Title, p.Description, p.AccessConfigUpdates)
}
// String implements the Stringer interface.
-func (c CodeAccessConfigUpdate) String() string {
- return fmt.Sprintf(`CodeAccessUpdate:
+func (c AccessConfigUpdate) String() string {
+ return fmt.Sprintf(`AccessConfigUpdate:
CodeID: %d
AccessConfig: %v
`, c.CodeID, c.InstantiatePermission)
diff --git a/x/wasm/types/proposal.pb.go b/x/wasm/types/proposal.pb.go
index 2a63aaf361..787bed1351 100644
--- a/x/wasm/types/proposal.pb.go
+++ b/x/wasm/types/proposal.pb.go
@@ -438,26 +438,26 @@ func (m *UnpinCodesProposal) XXX_DiscardUnknown() {
var xxx_messageInfo_UnpinCodesProposal proto.InternalMessageInfo
-// CodeAccessConfigUpdate contains the code id and the access config to be
+// AccessConfigUpdate contains the code id and the access config to be
// applied.
-type CodeAccessConfigUpdate struct {
+type AccessConfigUpdate struct {
// CodeID is the reference to the stored WASM code to be updated
CodeID uint64 `protobuf:"varint,1,opt,name=code_id,json=codeId,proto3" json:"code_id,omitempty"`
// InstantiatePermission to apply to the set of code ids
- InstantiatePermission AccessConfig `protobuf:"bytes,4,opt,name=instantiate_permission,json=instantiatePermission,proto3" json:"instantiate_permission"`
+ InstantiatePermission AccessConfig `protobuf:"bytes,2,opt,name=instantiate_permission,json=instantiatePermission,proto3" json:"instantiate_permission"`
}
-func (m *CodeAccessConfigUpdate) Reset() { *m = CodeAccessConfigUpdate{} }
-func (*CodeAccessConfigUpdate) ProtoMessage() {}
-func (*CodeAccessConfigUpdate) Descriptor() ([]byte, []int) {
+func (m *AccessConfigUpdate) Reset() { *m = AccessConfigUpdate{} }
+func (*AccessConfigUpdate) ProtoMessage() {}
+func (*AccessConfigUpdate) Descriptor() ([]byte, []int) {
return fileDescriptor_be6422d717c730cb, []int{9}
}
-func (m *CodeAccessConfigUpdate) XXX_Unmarshal(b []byte) error {
+func (m *AccessConfigUpdate) XXX_Unmarshal(b []byte) error {
return m.Unmarshal(b)
}
-func (m *CodeAccessConfigUpdate) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+func (m *AccessConfigUpdate) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
if deterministic {
- return xxx_messageInfo_CodeAccessConfigUpdate.Marshal(b, m, deterministic)
+ return xxx_messageInfo_AccessConfigUpdate.Marshal(b, m, deterministic)
} else {
b = b[:cap(b)]
n, err := m.MarshalToSizedBuffer(b)
@@ -467,17 +467,17 @@ func (m *CodeAccessConfigUpdate) XXX_Marshal(b []byte, deterministic bool) ([]by
return b[:n], nil
}
}
-func (m *CodeAccessConfigUpdate) XXX_Merge(src proto.Message) {
- xxx_messageInfo_CodeAccessConfigUpdate.Merge(m, src)
+func (m *AccessConfigUpdate) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_AccessConfigUpdate.Merge(m, src)
}
-func (m *CodeAccessConfigUpdate) XXX_Size() int {
+func (m *AccessConfigUpdate) XXX_Size() int {
return m.Size()
}
-func (m *CodeAccessConfigUpdate) XXX_DiscardUnknown() {
- xxx_messageInfo_CodeAccessConfigUpdate.DiscardUnknown(m)
+func (m *AccessConfigUpdate) XXX_DiscardUnknown() {
+ xxx_messageInfo_AccessConfigUpdate.DiscardUnknown(m)
}
-var xxx_messageInfo_CodeAccessConfigUpdate proto.InternalMessageInfo
+var xxx_messageInfo_AccessConfigUpdate proto.InternalMessageInfo
// UpdateInstantiateConfigProposal gov proposal content type to update
// instantiate config to a set of code ids.
@@ -486,9 +486,9 @@ type UpdateInstantiateConfigProposal struct {
Title string `protobuf:"bytes,1,opt,name=title,proto3" json:"title,omitempty" yaml:"title"`
// Description is a human readable text
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty" yaml:"description"`
- // CodeAccessConfigUpdate contains the list of code ids and the access config
+ // AccessConfigUpdate contains the list of code ids and the access config
// to be applied.
- CodeUpdates []CodeAccessConfigUpdate `protobuf:"bytes,3,rep,name=code_updates,json=codeUpdates,proto3" json:"code_updates"`
+ AccessConfigUpdates []AccessConfigUpdate `protobuf:"bytes,3,rep,name=access_config_updates,json=accessConfigUpdates,proto3" json:"access_config_updates"`
}
func (m *UpdateInstantiateConfigProposal) Reset() { *m = UpdateInstantiateConfigProposal{} }
@@ -533,65 +533,66 @@ func init() {
proto.RegisterType((*ClearAdminProposal)(nil), "cosmwasm.wasm.v1.ClearAdminProposal")
proto.RegisterType((*PinCodesProposal)(nil), "cosmwasm.wasm.v1.PinCodesProposal")
proto.RegisterType((*UnpinCodesProposal)(nil), "cosmwasm.wasm.v1.UnpinCodesProposal")
- proto.RegisterType((*CodeAccessConfigUpdate)(nil), "cosmwasm.wasm.v1.CodeAccessConfigUpdate")
+ proto.RegisterType((*AccessConfigUpdate)(nil), "cosmwasm.wasm.v1.AccessConfigUpdate")
proto.RegisterType((*UpdateInstantiateConfigProposal)(nil), "cosmwasm.wasm.v1.UpdateInstantiateConfigProposal")
}
func init() { proto.RegisterFile("cosmwasm/wasm/v1/proposal.proto", fileDescriptor_be6422d717c730cb) }
var fileDescriptor_be6422d717c730cb = []byte{
- // 813 bytes of a gzipped FileDescriptorProto
+ // 817 bytes of a gzipped FileDescriptorProto
0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xd4, 0x56, 0x4f, 0x6f, 0xe3, 0x44,
- 0x14, 0xcf, 0x34, 0x8e, 0x93, 0x4e, 0x22, 0x08, 0x26, 0x9b, 0x0d, 0x05, 0xd9, 0x91, 0x91, 0x56,
- 0xbe, 0x60, 0x93, 0x22, 0x21, 0xe0, 0x16, 0x07, 0x0e, 0x5d, 0x51, 0xa9, 0xb8, 0xaa, 0x56, 0x82,
- 0x43, 0x34, 0xb1, 0xa7, 0x5e, 0x8b, 0xd8, 0x63, 0x79, 0x26, 0xcd, 0xe6, 0x5b, 0x80, 0xc4, 0x09,
- 0xf1, 0x01, 0x10, 0x17, 0xc4, 0x9d, 0x0f, 0x50, 0x71, 0xda, 0x13, 0xda, 0x93, 0x61, 0xd3, 0x6f,
- 0x90, 0x23, 0x12, 0x12, 0x9a, 0x19, 0x27, 0xa4, 0xff, 0x8b, 0x68, 0x90, 0xb8, 0x38, 0x79, 0xf3,
- 0xde, 0x9b, 0xf7, 0x9b, 0x9f, 0x7e, 0x6f, 0xde, 0x40, 0xc3, 0x27, 0x34, 0x9e, 0x22, 0x1a, 0x3b,
- 0xe2, 0x73, 0xd2, 0x73, 0xd2, 0x8c, 0xa4, 0x84, 0xa2, 0xb1, 0x9d, 0x66, 0x84, 0x11, 0xad, 0xb9,
- 0x0c, 0xb0, 0xc5, 0xe7, 0xa4, 0xb7, 0xd3, 0x0a, 0x49, 0x48, 0x84, 0xd3, 0xe1, 0xff, 0x64, 0xdc,
- 0x8e, 0xce, 0xe3, 0x08, 0x75, 0x46, 0x88, 0x62, 0xe7, 0xa4, 0x37, 0xc2, 0x0c, 0xf5, 0x1c, 0x9f,
- 0x44, 0x49, 0xe1, 0x7f, 0xeb, 0x52, 0x21, 0x36, 0x4b, 0x31, 0x95, 0x5e, 0xf3, 0x4f, 0x00, 0x5f,
- 0x3b, 0x64, 0x24, 0xc3, 0x03, 0x12, 0xe0, 0x83, 0x02, 0x81, 0xd6, 0x82, 0x15, 0x16, 0xb1, 0x31,
- 0xee, 0x80, 0x2e, 0xb0, 0xb6, 0x3d, 0x69, 0x68, 0x5d, 0x58, 0x0f, 0x30, 0xf5, 0xb3, 0x28, 0x65,
- 0x11, 0x49, 0x3a, 0x5b, 0xc2, 0xb7, 0xbe, 0xa4, 0x3d, 0x80, 0x6a, 0x36, 0x49, 0x86, 0x88, 0x76,
- 0xca, 0x32, 0x31, 0x9b, 0x24, 0x7d, 0xaa, 0xbd, 0x0f, 0x5f, 0xe1, 0xb5, 0x87, 0xa3, 0x19, 0xc3,
- 0x43, 0x9f, 0x04, 0xb8, 0xa3, 0x74, 0x81, 0xd5, 0x70, 0x9b, 0xf3, 0xdc, 0x68, 0x3c, 0xe9, 0x1f,
- 0xee, 0xbb, 0x33, 0x26, 0x00, 0x78, 0x0d, 0x1e, 0xb7, 0xb4, 0xb4, 0x23, 0xd8, 0x8e, 0x12, 0xca,
- 0x50, 0xc2, 0x22, 0xc4, 0xf0, 0x30, 0xc5, 0x59, 0x1c, 0x51, 0xca, 0x6b, 0x57, 0xbb, 0xc0, 0xaa,
- 0xef, 0xea, 0xf6, 0x45, 0x8e, 0xec, 0xbe, 0xef, 0x63, 0x4a, 0x07, 0x24, 0x39, 0x8e, 0x42, 0xef,
- 0xc1, 0x5a, 0xf6, 0xc1, 0x2a, 0xf9, 0xb1, 0x52, 0xab, 0x34, 0xd5, 0xc7, 0x4a, 0x4d, 0x6d, 0x56,
- 0xcd, 0x5f, 0xb6, 0xe0, 0x9b, 0x7b, 0x7f, 0x47, 0x0d, 0x48, 0xc2, 0x32, 0xe4, 0xb3, 0x4d, 0x31,
- 0xd1, 0x82, 0x15, 0x14, 0xc4, 0x51, 0x22, 0x08, 0xd8, 0xf6, 0xa4, 0xa1, 0xbd, 0x0d, 0xab, 0x9c,
- 0x95, 0x61, 0x14, 0x74, 0x2a, 0x5d, 0x60, 0x29, 0x2e, 0x9c, 0xe7, 0x86, 0xca, 0x29, 0xd8, 0xfb,
- 0xd8, 0x53, 0xb9, 0x6b, 0x2f, 0xe0, 0xa9, 0x63, 0x34, 0xc2, 0xe3, 0x8e, 0x2a, 0x53, 0x85, 0xa1,
- 0x59, 0xb0, 0x1c, 0xd3, 0x50, 0xf0, 0xd1, 0x70, 0xdb, 0x7f, 0xe4, 0x86, 0xe6, 0xa1, 0xe9, 0xf2,
- 0x14, 0xfb, 0x98, 0x52, 0x14, 0x62, 0x8f, 0x87, 0x68, 0x08, 0x56, 0x8e, 0x27, 0x49, 0x40, 0x3b,
- 0xb5, 0x6e, 0xd9, 0xaa, 0xef, 0xbe, 0x61, 0x4b, 0xdd, 0xd8, 0x5c, 0x37, 0x76, 0xa1, 0x1b, 0x7b,
- 0x40, 0xa2, 0xc4, 0x7d, 0xf7, 0x34, 0x37, 0x4a, 0x3f, 0xfc, 0x66, 0x58, 0x61, 0xc4, 0x9e, 0x4e,
- 0x46, 0xb6, 0x4f, 0x62, 0xa7, 0x10, 0x99, 0xfc, 0x79, 0x87, 0x06, 0x5f, 0x16, 0x2a, 0xe2, 0x09,
- 0xd4, 0x93, 0x3b, 0x9b, 0x3f, 0x03, 0xf8, 0x70, 0x3f, 0x0a, 0xb3, 0xfb, 0x24, 0x72, 0x07, 0xd6,
- 0xfc, 0x62, 0xaf, 0x82, 0xb4, 0x95, 0x7d, 0x37, 0xde, 0x0a, 0x86, 0xd4, 0x5b, 0x19, 0x32, 0xbf,
- 0x01, 0xb0, 0x75, 0x38, 0x09, 0xc8, 0x46, 0xb0, 0x97, 0x2f, 0x60, 0x2f, 0x60, 0x29, 0xb7, 0xc3,
- 0xfa, 0x7a, 0x0b, 0x3e, 0xfc, 0xe4, 0x19, 0xf6, 0x27, 0x9b, 0x97, 0xe7, 0x4d, 0x64, 0x17, 0x80,
- 0x2b, 0xff, 0x40, 0x69, 0xea, 0xc6, 0x94, 0xf6, 0x1d, 0x80, 0xaf, 0x1f, 0xa5, 0x01, 0x62, 0xb8,
- 0xcf, 0x3b, 0xe8, 0x5f, 0xf3, 0xd1, 0x83, 0xdb, 0x09, 0x9e, 0x0e, 0x65, 0x6f, 0x0a, 0x4a, 0xdc,
- 0xd6, 0x22, 0x37, 0x9a, 0x33, 0x14, 0x8f, 0x3f, 0x32, 0x57, 0x2e, 0xd3, 0xab, 0x25, 0x78, 0x2a,
- 0x4a, 0xde, 0xc4, 0x95, 0xf9, 0x14, 0x6a, 0x83, 0x31, 0x46, 0xd9, 0xfd, 0x80, 0xbb, 0x41, 0x46,
- 0xe6, 0x8f, 0x00, 0x36, 0x0f, 0xa2, 0x84, 0x6b, 0x9e, 0xae, 0x0a, 0x3d, 0x3a, 0x57, 0xc8, 0x6d,
- 0x2e, 0x72, 0xa3, 0x21, 0x4f, 0x22, 0x96, 0xcd, 0x65, 0xe9, 0x0f, 0xae, 0x28, 0xed, 0xb6, 0x17,
- 0xb9, 0xa1, 0xc9, 0xe8, 0x35, 0xa7, 0x79, 0x1e, 0xd2, 0x87, 0x1c, 0x92, 0xe8, 0x3c, 0xae, 0xa0,
- 0xb2, 0xa5, 0xb8, 0xfa, 0x3c, 0x37, 0xaa, 0xb2, 0xf5, 0xe8, 0x22, 0x37, 0x5e, 0x95, 0x3b, 0x2c,
- 0x83, 0x4c, 0xaf, 0x2a, 0xdb, 0x91, 0x9a, 0x3f, 0x01, 0xa8, 0x1d, 0x25, 0xe9, 0xff, 0x0a, 0xf3,
- 0xb7, 0x00, 0xb6, 0x79, 0xdc, 0xfa, 0x74, 0x91, 0xf2, 0x5b, 0xbf, 0x83, 0xc0, 0xb5, 0x77, 0xd0,
- 0x17, 0xd7, 0x0e, 0x32, 0xe5, 0x2e, 0x83, 0xcc, 0x55, 0x78, 0x9f, 0x5c, 0x33, 0xce, 0xcc, 0x5f,
- 0x01, 0x34, 0x24, 0x98, 0xf3, 0x83, 0xec, 0x38, 0x0a, 0xff, 0x43, 0x76, 0x3f, 0x83, 0x0d, 0xc1,
- 0xc3, 0x44, 0x20, 0x91, 0x0c, 0xd7, 0x77, 0xad, 0xcb, 0x07, 0xbb, 0x9a, 0xc7, 0xe2, 0x88, 0x75,
- 0xbe, 0x87, 0x5c, 0xa1, 0xee, 0xa7, 0xa7, 0x2f, 0xf5, 0xd2, 0x8b, 0x97, 0x7a, 0xe9, 0xfb, 0xb9,
- 0x0e, 0x4e, 0xe7, 0x3a, 0x78, 0x3e, 0xd7, 0xc1, 0xef, 0x73, 0x1d, 0x7c, 0x75, 0xa6, 0x97, 0x9e,
- 0x9f, 0xe9, 0xa5, 0x17, 0x67, 0x7a, 0xe9, 0xf3, 0x47, 0x6b, 0x77, 0xc7, 0x80, 0xd0, 0xf8, 0xc9,
- 0xf2, 0xa9, 0x13, 0x38, 0xcf, 0xe4, 0x93, 0x47, 0xdc, 0x1f, 0x23, 0x55, 0x3c, 0x78, 0xde, 0xfb,
- 0x2b, 0x00, 0x00, 0xff, 0xff, 0xad, 0x12, 0x0a, 0xc1, 0x79, 0x09, 0x00, 0x00,
+ 0x14, 0xcf, 0xe4, 0x8f, 0x93, 0x4e, 0x22, 0x08, 0xde, 0xb4, 0x1b, 0x0a, 0xb2, 0x23, 0x83, 0x56,
+ 0xbe, 0x60, 0x93, 0x22, 0x21, 0xe0, 0x16, 0x07, 0x0e, 0x5d, 0x51, 0xa9, 0x72, 0x55, 0xad, 0x04,
+ 0x12, 0xd6, 0xc4, 0x9e, 0x7a, 0x2d, 0x62, 0x8f, 0xe5, 0x99, 0x34, 0x9b, 0x6f, 0x01, 0x12, 0xe2,
+ 0xc4, 0x07, 0x40, 0x5c, 0x10, 0x77, 0x3e, 0x40, 0xc5, 0x69, 0x8f, 0x7b, 0x32, 0x6c, 0xf2, 0x0d,
+ 0x72, 0x44, 0x42, 0x42, 0x33, 0xe3, 0x84, 0x74, 0x97, 0x66, 0x17, 0xd1, 0x20, 0x71, 0x71, 0xf2,
+ 0xe6, 0xbd, 0x37, 0xef, 0x37, 0x3f, 0xfd, 0xde, 0xbc, 0x81, 0xba, 0x4f, 0x68, 0x3c, 0x45, 0x34,
+ 0xb6, 0xc5, 0xe7, 0xb2, 0x6f, 0xa7, 0x19, 0x49, 0x09, 0x45, 0x63, 0x2b, 0xcd, 0x08, 0x23, 0x6a,
+ 0x7b, 0x15, 0x60, 0x89, 0xcf, 0x65, 0xff, 0xb0, 0x13, 0x92, 0x90, 0x08, 0xa7, 0xcd, 0xff, 0xc9,
+ 0xb8, 0x43, 0x8d, 0xc7, 0x11, 0x6a, 0x8f, 0x10, 0xc5, 0xf6, 0x65, 0x7f, 0x84, 0x19, 0xea, 0xdb,
+ 0x3e, 0x89, 0x92, 0xc2, 0xff, 0xe6, 0x73, 0x85, 0xd8, 0x2c, 0xc5, 0x54, 0x7a, 0x8d, 0x3f, 0x00,
+ 0x7c, 0xed, 0x8c, 0x91, 0x0c, 0x0f, 0x49, 0x80, 0x4f, 0x0b, 0x04, 0x6a, 0x07, 0xd6, 0x58, 0xc4,
+ 0xc6, 0xb8, 0x0b, 0x7a, 0xc0, 0xdc, 0x73, 0xa5, 0xa1, 0xf6, 0x60, 0x33, 0xc0, 0xd4, 0xcf, 0xa2,
+ 0x94, 0x45, 0x24, 0xe9, 0x96, 0x85, 0x6f, 0x73, 0x49, 0xdd, 0x87, 0x4a, 0x36, 0x49, 0x3c, 0x44,
+ 0xbb, 0x15, 0x99, 0x98, 0x4d, 0x92, 0x01, 0x55, 0xdf, 0x87, 0xaf, 0xf0, 0xda, 0xde, 0x68, 0xc6,
+ 0xb0, 0xe7, 0x93, 0x00, 0x77, 0xab, 0x3d, 0x60, 0xb6, 0x9c, 0xf6, 0x3c, 0xd7, 0x5b, 0x0f, 0x06,
+ 0x67, 0x27, 0xce, 0x8c, 0x09, 0x00, 0x6e, 0x8b, 0xc7, 0xad, 0x2c, 0xf5, 0x1c, 0x1e, 0x44, 0x09,
+ 0x65, 0x28, 0x61, 0x11, 0x62, 0xd8, 0x4b, 0x71, 0x16, 0x47, 0x94, 0xf2, 0xda, 0xf5, 0x1e, 0x30,
+ 0x9b, 0x47, 0x9a, 0xf5, 0x2c, 0x47, 0xd6, 0xc0, 0xf7, 0x31, 0xa5, 0x43, 0x92, 0x5c, 0x44, 0xa1,
+ 0xbb, 0xbf, 0x91, 0x7d, 0xba, 0x4e, 0xbe, 0x5f, 0x6d, 0xd4, 0xda, 0xca, 0xfd, 0x6a, 0x43, 0x69,
+ 0xd7, 0x8d, 0x5f, 0xca, 0xf0, 0x8d, 0xe3, 0xbf, 0xa2, 0x86, 0x24, 0x61, 0x19, 0xf2, 0xd9, 0xae,
+ 0x98, 0xe8, 0xc0, 0x1a, 0x0a, 0xe2, 0x28, 0x11, 0x04, 0xec, 0xb9, 0xd2, 0x50, 0xdf, 0x82, 0x75,
+ 0xce, 0x8a, 0x17, 0x05, 0xdd, 0x5a, 0x0f, 0x98, 0x55, 0x07, 0xce, 0x73, 0x5d, 0xe1, 0x14, 0x1c,
+ 0x7f, 0xec, 0x2a, 0xdc, 0x75, 0x1c, 0xf0, 0xd4, 0x31, 0x1a, 0xe1, 0x71, 0x57, 0x91, 0xa9, 0xc2,
+ 0x50, 0x4d, 0x58, 0x89, 0x69, 0x28, 0xf8, 0x68, 0x39, 0x07, 0xbf, 0xe7, 0xba, 0xea, 0xa2, 0xe9,
+ 0xea, 0x14, 0x27, 0x98, 0x52, 0x14, 0x62, 0x97, 0x87, 0xa8, 0x08, 0xd6, 0x2e, 0x26, 0x49, 0x40,
+ 0xbb, 0x8d, 0x5e, 0xc5, 0x6c, 0x1e, 0xbd, 0x6e, 0x49, 0xdd, 0x58, 0x5c, 0x37, 0x56, 0xa1, 0x1b,
+ 0x6b, 0x48, 0xa2, 0xc4, 0x79, 0xf7, 0x2a, 0xd7, 0x4b, 0x3f, 0xfc, 0xaa, 0x9b, 0x61, 0xc4, 0x1e,
+ 0x4e, 0x46, 0x96, 0x4f, 0x62, 0xbb, 0x10, 0x99, 0xfc, 0x79, 0x87, 0x06, 0x5f, 0x16, 0x2a, 0xe2,
+ 0x09, 0xd4, 0x95, 0x3b, 0x1b, 0x3f, 0x03, 0x78, 0xf7, 0x24, 0x0a, 0xb3, 0xdb, 0x24, 0xf2, 0x10,
+ 0x36, 0xfc, 0x62, 0xaf, 0x82, 0xb4, 0xb5, 0xfd, 0x72, 0xbc, 0x15, 0x0c, 0x29, 0x2f, 0x64, 0xc8,
+ 0xf8, 0x06, 0xc0, 0xce, 0xd9, 0x24, 0x20, 0x3b, 0xc1, 0x5e, 0x79, 0x06, 0x7b, 0x01, 0xab, 0xfa,
+ 0x62, 0x58, 0x5f, 0x97, 0xe1, 0xdd, 0x4f, 0x1e, 0x61, 0x7f, 0xb2, 0x7b, 0x79, 0x6e, 0x23, 0xbb,
+ 0x00, 0x5c, 0xfb, 0x07, 0x4a, 0x53, 0x76, 0xa6, 0xb4, 0xef, 0x00, 0xbc, 0x73, 0x9e, 0x06, 0x88,
+ 0xe1, 0x01, 0xef, 0xa0, 0x7f, 0xcd, 0x47, 0x1f, 0xee, 0x25, 0x78, 0xea, 0xc9, 0xde, 0x14, 0x94,
+ 0x38, 0x9d, 0x65, 0xae, 0xb7, 0x67, 0x28, 0x1e, 0x7f, 0x64, 0xac, 0x5d, 0x86, 0xdb, 0x48, 0xf0,
+ 0x54, 0x94, 0xdc, 0xc6, 0x95, 0xf1, 0x10, 0xaa, 0xc3, 0x31, 0x46, 0xd9, 0xed, 0x80, 0xdb, 0x22,
+ 0x23, 0xe3, 0x47, 0x00, 0xdb, 0xa7, 0x51, 0xc2, 0x35, 0x4f, 0xd7, 0x85, 0xee, 0x5d, 0x2b, 0xe4,
+ 0xb4, 0x97, 0xb9, 0xde, 0x92, 0x27, 0x11, 0xcb, 0xc6, 0xaa, 0xf4, 0x07, 0x7f, 0x53, 0xda, 0x39,
+ 0x58, 0xe6, 0xba, 0x2a, 0xa3, 0x37, 0x9c, 0xc6, 0x75, 0x48, 0x1f, 0x72, 0x48, 0xa2, 0xf3, 0xb8,
+ 0x82, 0x2a, 0x66, 0xd5, 0xd1, 0xe6, 0xb9, 0x5e, 0x97, 0xad, 0x47, 0x97, 0xb9, 0xfe, 0xaa, 0xdc,
+ 0x61, 0x15, 0x64, 0xb8, 0x75, 0xd9, 0x8e, 0xd4, 0xf8, 0x09, 0x40, 0xf5, 0x3c, 0x49, 0xff, 0x57,
+ 0x98, 0xbf, 0x05, 0x50, 0xdd, 0x9c, 0x2c, 0x52, 0x7a, 0x9b, 0xf7, 0x0f, 0xb8, 0xf1, 0xfe, 0xf9,
+ 0xfc, 0xc6, 0x21, 0x56, 0x7e, 0x99, 0x21, 0xe6, 0x54, 0x79, 0x8f, 0xdc, 0x30, 0xca, 0x8c, 0x05,
+ 0x80, 0xba, 0x04, 0x73, 0x7d, 0x88, 0x5d, 0x44, 0xe1, 0x7f, 0xc8, 0xec, 0x17, 0x70, 0x1f, 0x09,
+ 0xc8, 0x9e, 0x2f, 0x4a, 0x7b, 0x13, 0x01, 0x49, 0xd2, 0xdc, 0x3c, 0x7a, 0x7b, 0xfb, 0x09, 0x25,
+ 0xfe, 0xe2, 0x9c, 0x77, 0xd0, 0x73, 0x1e, 0xea, 0x7c, 0x7a, 0xf5, 0x54, 0x2b, 0x3d, 0x79, 0xaa,
+ 0x95, 0xbe, 0x9f, 0x6b, 0xe0, 0x6a, 0xae, 0x81, 0xc7, 0x73, 0x0d, 0xfc, 0x36, 0xd7, 0xc0, 0x57,
+ 0x0b, 0xad, 0xf4, 0x78, 0xa1, 0x95, 0x9e, 0x2c, 0xb4, 0xd2, 0x67, 0xf7, 0x36, 0x2e, 0x91, 0x21,
+ 0xa1, 0xf1, 0x83, 0xd5, 0x9b, 0x27, 0xb0, 0x1f, 0xc9, 0xb7, 0x8f, 0xb8, 0x48, 0x46, 0x8a, 0x78,
+ 0xf9, 0xbc, 0xf7, 0x67, 0x00, 0x00, 0x00, 0xff, 0xff, 0x70, 0x3f, 0xe6, 0xf2, 0x82, 0x09, 0x00,
+ 0x00,
}
func (this *StoreCodeProposal) Equal(that interface{}) bool {
@@ -926,14 +927,14 @@ func (this *UnpinCodesProposal) Equal(that interface{}) bool {
}
return true
}
-func (this *CodeAccessConfigUpdate) Equal(that interface{}) bool {
+func (this *AccessConfigUpdate) Equal(that interface{}) bool {
if that == nil {
return this == nil
}
- that1, ok := that.(*CodeAccessConfigUpdate)
+ that1, ok := that.(*AccessConfigUpdate)
if !ok {
- that2, ok := that.(CodeAccessConfigUpdate)
+ that2, ok := that.(AccessConfigUpdate)
if ok {
that1 = &that2
} else {
@@ -978,11 +979,11 @@ func (this *UpdateInstantiateConfigProposal) Equal(that interface{}) bool {
if this.Description != that1.Description {
return false
}
- if len(this.CodeUpdates) != len(that1.CodeUpdates) {
+ if len(this.AccessConfigUpdates) != len(that1.AccessConfigUpdates) {
return false
}
- for i := range this.CodeUpdates {
- if !this.CodeUpdates[i].Equal(&that1.CodeUpdates[i]) {
+ for i := range this.AccessConfigUpdates {
+ if !this.AccessConfigUpdates[i].Equal(&that1.AccessConfigUpdates[i]) {
return false
}
}
@@ -1519,7 +1520,7 @@ func (m *UnpinCodesProposal) MarshalToSizedBuffer(dAtA []byte) (int, error) {
return len(dAtA) - i, nil
}
-func (m *CodeAccessConfigUpdate) Marshal() (dAtA []byte, err error) {
+func (m *AccessConfigUpdate) Marshal() (dAtA []byte, err error) {
size := m.Size()
dAtA = make([]byte, size)
n, err := m.MarshalToSizedBuffer(dAtA[:size])
@@ -1529,12 +1530,12 @@ func (m *CodeAccessConfigUpdate) Marshal() (dAtA []byte, err error) {
return dAtA[:n], nil
}
-func (m *CodeAccessConfigUpdate) MarshalTo(dAtA []byte) (int, error) {
+func (m *AccessConfigUpdate) MarshalTo(dAtA []byte) (int, error) {
size := m.Size()
return m.MarshalToSizedBuffer(dAtA[:size])
}
-func (m *CodeAccessConfigUpdate) MarshalToSizedBuffer(dAtA []byte) (int, error) {
+func (m *AccessConfigUpdate) MarshalToSizedBuffer(dAtA []byte) (int, error) {
i := len(dAtA)
_ = i
var l int
@@ -1548,7 +1549,7 @@ func (m *CodeAccessConfigUpdate) MarshalToSizedBuffer(dAtA []byte) (int, error)
i = encodeVarintProposal(dAtA, i, uint64(size))
}
i--
- dAtA[i] = 0x22
+ dAtA[i] = 0x12
if m.CodeID != 0 {
i = encodeVarintProposal(dAtA, i, uint64(m.CodeID))
i--
@@ -1577,10 +1578,10 @@ func (m *UpdateInstantiateConfigProposal) MarshalToSizedBuffer(dAtA []byte) (int
_ = i
var l int
_ = l
- if len(m.CodeUpdates) > 0 {
- for iNdEx := len(m.CodeUpdates) - 1; iNdEx >= 0; iNdEx-- {
+ if len(m.AccessConfigUpdates) > 0 {
+ for iNdEx := len(m.AccessConfigUpdates) - 1; iNdEx >= 0; iNdEx-- {
{
- size, err := m.CodeUpdates[iNdEx].MarshalToSizedBuffer(dAtA[:i])
+ size, err := m.AccessConfigUpdates[iNdEx].MarshalToSizedBuffer(dAtA[:i])
if err != nil {
return 0, err
}
@@ -1872,7 +1873,7 @@ func (m *UnpinCodesProposal) Size() (n int) {
return n
}
-func (m *CodeAccessConfigUpdate) Size() (n int) {
+func (m *AccessConfigUpdate) Size() (n int) {
if m == nil {
return 0
}
@@ -1900,8 +1901,8 @@ func (m *UpdateInstantiateConfigProposal) Size() (n int) {
if l > 0 {
n += 1 + l + sovProposal(uint64(l))
}
- if len(m.CodeUpdates) > 0 {
- for _, e := range m.CodeUpdates {
+ if len(m.AccessConfigUpdates) > 0 {
+ for _, e := range m.AccessConfigUpdates {
l = e.Size()
n += 1 + l + sovProposal(uint64(l))
}
@@ -3757,7 +3758,7 @@ func (m *UnpinCodesProposal) Unmarshal(dAtA []byte) error {
}
return nil
}
-func (m *CodeAccessConfigUpdate) Unmarshal(dAtA []byte) error {
+func (m *AccessConfigUpdate) Unmarshal(dAtA []byte) error {
l := len(dAtA)
iNdEx := 0
for iNdEx < l {
@@ -3780,10 +3781,10 @@ func (m *CodeAccessConfigUpdate) Unmarshal(dAtA []byte) error {
fieldNum := int32(wire >> 3)
wireType := int(wire & 0x7)
if wireType == 4 {
- return fmt.Errorf("proto: CodeAccessConfigUpdate: wiretype end group for non-group")
+ return fmt.Errorf("proto: AccessConfigUpdate: wiretype end group for non-group")
}
if fieldNum <= 0 {
- return fmt.Errorf("proto: CodeAccessConfigUpdate: illegal tag %d (wire type %d)", fieldNum, wire)
+ return fmt.Errorf("proto: AccessConfigUpdate: illegal tag %d (wire type %d)", fieldNum, wire)
}
switch fieldNum {
case 1:
@@ -3805,7 +3806,7 @@ func (m *CodeAccessConfigUpdate) Unmarshal(dAtA []byte) error {
break
}
}
- case 4:
+ case 2:
if wireType != 2 {
return fmt.Errorf("proto: wrong wireType = %d for field InstantiatePermission", wireType)
}
@@ -3954,7 +3955,7 @@ func (m *UpdateInstantiateConfigProposal) Unmarshal(dAtA []byte) error {
iNdEx = postIndex
case 3:
if wireType != 2 {
- return fmt.Errorf("proto: wrong wireType = %d for field CodeUpdates", wireType)
+ return fmt.Errorf("proto: wrong wireType = %d for field AccessConfigUpdates", wireType)
}
var msglen int
for shift := uint(0); ; shift += 7 {
@@ -3981,8 +3982,8 @@ func (m *UpdateInstantiateConfigProposal) Unmarshal(dAtA []byte) error {
if postIndex > l {
return io.ErrUnexpectedEOF
}
- m.CodeUpdates = append(m.CodeUpdates, CodeAccessConfigUpdate{})
- if err := m.CodeUpdates[len(m.CodeUpdates)-1].Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
+ m.AccessConfigUpdates = append(m.AccessConfigUpdates, AccessConfigUpdate{})
+ if err := m.AccessConfigUpdates[len(m.AccessConfigUpdates)-1].Unmarshal(dAtA[iNdEx:postIndex]); err != nil {
return err
}
iNdEx = postIndex
diff --git a/proto/cosmwasm/wasm/v1/proposal.proto b/proto/cosmwasm/wasm/v1/proposal.proto
index 242c38811f..68eae73a12 100644
--- a/proto/cosmwasm/wasm/v1/proposal.proto
+++ b/proto/cosmwasm/wasm/v1/proposal.proto
@@ -149,13 +149,13 @@ message UnpinCodesProposal {
];
}
// CodeAccessConfigUpdate contains the code id and the access config to be
// applied.
-message CodeAccessConfigUpdate {
+message AccessConfigUpdate {
// CodeID is the reference to the stored WASM code to be updated
uint64 code_id = 1 [ (gogoproto.customname) = "CodeID" ];
// InstantiatePermission to apply to the set of code ids
- AccessConfig instantiate_permission = 4 [ (gogoproto.nullable) = false ];
+ AccessConfig instantiate_permission = 2 [ (gogoproto.nullable) = false ];
}
// UpdateInstantiateConfigProposal gov proposal content type to update
@@ -165,8 +165,8 @@ message UpdateInstantiateConfigProposal {
string title = 1 [ (gogoproto.moretags) = "yaml:\"title\"" ];
// Description is a human readable text
string description = 2 [ (gogoproto.moretags) = "yaml:\"description\"" ];
// CodeAccessConfigUpdate contains the list of code ids and the access config
// to be applied.
- repeated CodeAccessConfigUpdate code_updates = 3
+ repeated AccessConfigUpdate access_config_updates = 3
[ (gogoproto.nullable) = false ];
}
@@ -149,13 +149,13 @@ message UnpinCodesProposal {
];
}
-// CodeAccessConfigUpdate contains the code id and the access config to be
+// AccessConfigUpdate contains the code id and the access config to be
// applied.
@@ -165,8 +165,8 @@ message UpdateInstantiateConfigProposal {
// Description is a human readable text
string description = 2 [ (gogoproto.moretags) = "yaml:\"description\"" ];
- // CodeAccessConfigUpdate contains the list of code ids and the access config
+ // AccessConfigUpdate contains the list of code ids and the access config
// to be applied.